@@ -47,6 +47,75 @@ struct SystemdUnitDBusMessage
     QDBusObjectPath objectPath;
 };
 
+// --- Systemd D-Bus 类型定义开始 ---
+
+// 对应 Systemd ExecStart 的结构: (path, argv, ignore_failure) -> (sasb)
+struct SystemdExecCommand {
+    QString path;
+    QStringList args;
+    bool unclean; // 是否忽略错误
+};
+Q_DECLARE_METATYPE(SystemdExecCommand)
+
+// 对应 Systemd 属性结构: (name, value) -> (sv)
+struct SystemdProperty {
+    QString name;
+    QDBusVariant value; // 使用 QDBusVariant 来明确这是一个 Variant 容器
+};
+Q_DECLARE_METATYPE(SystemdProperty)
+
+// 对应 Systemd 辅助单元结构 (Aux Unit): (name, properties) -> (sa(sv))
+// StartTransientUnit 的第4个参数需要这个类型的数组，即使它是空的
+struct SystemdAux {
+    QString name;
+    QList<SystemdProperty> properties;
+};
+Q_DECLARE_METATYPE(SystemdAux)
+
+// 序列化操作符重载
+inline QDBusArgument &operator<<(QDBusArgument &arg, const SystemdExecCommand &cmd) {
+    arg.beginStructure();
+    arg << cmd.path << cmd.args << cmd.unclean;
+    arg.endStructure();
+    return arg;
+}
+
+inline const QDBusArgument &operator>>(const QDBusArgument &arg, SystemdExecCommand &cmd) {
+    arg.beginStructure();
+    arg >> cmd.path >> cmd.args >> cmd.unclean;
+    arg.endStructure();
+    return arg;
+}
+
+inline QDBusArgument &operator<<(QDBusArgument &arg, const SystemdProperty &prop) {
+    arg.beginStructure();
+    arg << prop.name << prop.value;
+    arg.endStructure();
+    return arg;
+}
+
+inline const QDBusArgument &operator>>(const QDBusArgument &arg, SystemdProperty &prop) {
+    arg.beginStructure();
+    arg >> prop.name >> prop.value;
+    arg.endStructure();
+    return arg;
+}
+
+inline QDBusArgument &operator<<(QDBusArgument &arg, const SystemdAux &aux) {
+    arg.beginStructure();
+    arg << aux.name << aux.properties;
+    arg.endStructure();
+    return arg;
+}
+
+inline const QDBusArgument &operator>>(const QDBusArgument &arg, SystemdAux &aux) {
+    arg.beginStructure();
+    arg >> aux.name >> aux.properties;
+    arg.endStructure();
+    return arg;
+}
+// --- Systemd D-Bus 类型定义结束 ---
+
 inline const QDBusArgument &operator>>(const QDBusArgument &argument, QStringMap &map)
 {
     argument.beginMap();
@@ -396,11 +465,6 @@ inline QString getXDGDataHome()
     return XDGDataHome;
 }
 
-inline QStringList getXDGSystemDirs()
-{
-    return QStringList{"/etc/xdg/autostart"};
-}
-
 inline QStringList getXDGDataDirs()
 {
     auto XDGDataDirs = QString::fromLocal8Bit(qgetenv("XDG_DATA_DIRS")).split(':', Qt::SkipEmptyParts);
@@ -410,26 +474,28 @@ inline QStringList getXDGDataDirs()
         XDGDataDirs.append("/usr/share");
     }
 
-    auto XDGDataHome = getXDGDataHome();
-    if (XDGDataDirs.contains(XDGDataHome)) {
-        XDGDataDirs.removeAll(XDGDataHome);
-    }
-
-    XDGDataDirs.push_front(XDGDataHome);
     return XDGDataDirs;
 }
 
+inline QStringList getXDGDataMergedDirs()
+{
+    QStringList merged;
+    merged.append(getXDGDataHome());
+    merged.append(getXDGDataDirs());
+    return merged;
+}
+
 inline QStringList getDesktopFileDirs()
 {
-    auto XDGDataDirs = getXDGDataDirs();
-    std::for_each(XDGDataDirs.begin(), XDGDataDirs.end(), [](QString &str) {
+    auto desktopFileDirs = getXDGDataMergedDirs();
+    std::for_each(desktopFileDirs.begin(), desktopFileDirs.end(), [](QString &str) {
         if (!str.endsWith(QDir::separator())) {
             str.append(QDir::separator());
         }
         str.append("applications");
     });
 
-    return XDGDataDirs;
+    return desktopFileDirs;
 }
 
 inline QString getXDGConfigHome()
@@ -449,27 +515,35 @@ inline QStringList getXDGConfigDirs()
         XDGConfigDirs.append("/etc/xdg");
     }
 
-    auto XDGConfigHome = getXDGConfigHome();
-
-    if (XDGConfigDirs.constFirst() != XDGConfigHome) {
-        XDGConfigDirs.removeAll(XDGConfigHome);
-        XDGConfigDirs.push_front(std::move(XDGConfigHome));  //  guarantee XDG_CONFIG_HOME is first element.
-    }
-
     return XDGConfigDirs;
 }
 
+inline QStringList getXDGConfigMergedDirs()
+{
+    QStringList merged;
+    merged.append(getXDGConfigHome());
+    merged.append(getXDGConfigDirs());
+    return merged;
+}
+
 inline QStringList getAutoStartDirs()
 {
-    auto XDGConfigDirs = getXDGConfigDirs();
-    std::for_each(XDGConfigDirs.begin(), XDGConfigDirs.end(), [](QString &str) {
+    auto autostartDirs = getXDGConfigMergedDirs();
+    std::for_each(autostartDirs.begin(), autostartDirs.end(), [](QString &str) {
         if (!str.endsWith(QDir::separator())) {
             str.append(QDir::separator());
         }
         str.append("autostart");
     });
 
-    return XDGConfigDirs;
+    return autostartDirs;
+}
+
+inline QStringList getMimeDirs()
+{
+    auto mimeDirs = getXDGConfigMergedDirs();
+    mimeDirs.append(getDesktopFileDirs());
+    return mimeDirs;
 }
 
 inline QString getCurrentDesktop()
